# CHANGELOG



## v0.8.0 (2023-09-18)

### Ci

* ci: clean up after debugging ([`8c7c8cb`](https://github.com/KennethEnevoldsen/asent/commit/8c7c8cb0a7170a4e0f634b59279c9eda3984aef2))

* ci: debug pyright ([`88db793`](https://github.com/KennethEnevoldsen/asent/commit/88db7932c1d524a2a7fd7fa07d2782052ebc9485))

* ci: test pyright ([`f06f307`](https://github.com/KennethEnevoldsen/asent/commit/f06f30776710a7409570549c6db8a9be366bb0a2))

* ci: update static type check ci ([`f3c7235`](https://github.com/KennethEnevoldsen/asent/commit/f3c7235ab6ae78a49814c3f12bd554ede739ce75))

### Fix

* fix: issue with cmap ([`1bbaa6a`](https://github.com/KennethEnevoldsen/asent/commit/1bbaa6a13a38907dffb1d147cf6c75c4b2ec9492))

### Unknown

* Merge pull request #159 from KennethEnevoldsen/add_functionality_for_multiprocessing

Add functionality for multiprocessing ([`93f5b2e`](https://github.com/KennethEnevoldsen/asent/commit/93f5b2e86bacafab761640f4d178eafd39acbec9))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent into add_functionality_for_multiprocessing ([`ce2a7ff`](https://github.com/KennethEnevoldsen/asent/commit/ce2a7ffcb93fe8f810fa99cd8fb151eb3b8582c4))


## v0.7.9 (2023-09-18)

### Fix

* fix: static type check ([`0c4a0ae`](https://github.com/KennethEnevoldsen/asent/commit/0c4a0ae4211bad1d868685c59c54014cf6339278))

### Unknown

* Merge branch &#39;main&#39; into add_functionality_for_multiprocessing ([`7f92e18`](https://github.com/KennethEnevoldsen/asent/commit/7f92e1896e496609586782b1557d5cabde3e93d0))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent ([`d7bd5a9`](https://github.com/KennethEnevoldsen/asent/commit/d7bd5a9722831dcd74944ea9314b1105deef842b))


## v0.7.8 (2023-09-18)

### Ci

* ci: update static type check ([`a728945`](https://github.com/KennethEnevoldsen/asent/commit/a728945fdee8945aeb1587bf8d3cb76d8d12d77d))

### Unknown

* Merge branches &#39;main&#39; and &#39;main&#39; of https://github.com/KennethEnevoldsen/asent ([`db5bc4a`](https://github.com/KennethEnevoldsen/asent/commit/db5bc4a3e3bb1c57b1889181844266a259300cbc))


## v0.7.7 (2023-09-18)

### Ci

* ci: clean up static type check ci ([`8f3e8df`](https://github.com/KennethEnevoldsen/asent/commit/8f3e8df9c1d7ce45bb6773eb6edaf98e9914d850))

* ci: fix ci for docs ([`69925b2`](https://github.com/KennethEnevoldsen/asent/commit/69925b2306c255119889c0f4493309a03a4b5ff1))

* ci: debug pyright ([`0bb6984`](https://github.com/KennethEnevoldsen/asent/commit/0bb6984d5af407648e06a27c48907558c7897cef))

* ci: debug pyright ([`71f042c`](https://github.com/KennethEnevoldsen/asent/commit/71f042c503efdc2dcc79ea3ee3d02f09e9c3b6ca))

* ci: debugging static type check ([`698143e`](https://github.com/KennethEnevoldsen/asent/commit/698143efe35b719c2b4e1fc590990a0a71701227))

### Feature

* feat: updated pre-commit ([`0e9c61c`](https://github.com/KennethEnevoldsen/asent/commit/0e9c61cbddfaf82260b4849e2a472d4ea563c6a3))

### Fix

* fix: ran static type check ([`a155574`](https://github.com/KennethEnevoldsen/asent/commit/a155574bd3c4303c73c1582fa6f49bb66a2728db))

* fix: ran static type check ([`bc96a20`](https://github.com/KennethEnevoldsen/asent/commit/bc96a20bdc4ce898f5258efb6f1617eba24cc1df))

* fix: unsure dynamic function is not hidden ([`a3e3d98`](https://github.com/KennethEnevoldsen/asent/commit/a3e3d9840933ab8217be9518cc6287e8146d3437))

* fix: ran static type checks ([`26429fa`](https://github.com/KennethEnevoldsen/asent/commit/26429faec5861a61ae83af112ad6bac444c81147))

* fix: hide component utility function from docs ([`60d3c63`](https://github.com/KennethEnevoldsen/asent/commit/60d3c637742586065af8d07f2573962b942eea6c))

* fix: remove type hints for docstrings ([`341ecdb`](https://github.com/KennethEnevoldsen/asent/commit/341ecdbe6bdc5fca387fb6caff6dab301bb4b0a1))

### Unknown

* add mult. proc functionality ([`d754016`](https://github.com/KennethEnevoldsen/asent/commit/d754016908c4e3c1f1ef538b716ba405c41fd324))


## v0.7.6 (2023-09-04)

### Chore

* chore: remove tox files ([`57660c5`](https://github.com/KennethEnevoldsen/asent/commit/57660c5bb675cb818bad52a55a609f48f5d32f27))

* chore: remove .venv from gitignore ([`6a5f534`](https://github.com/KennethEnevoldsen/asent/commit/6a5f5340c852807c08efa44822e92df2152bfd51))

### Ci

* ci: fix pytest ci ([`7365765`](https://github.com/KennethEnevoldsen/asent/commit/7365765f3cfd867c3bd7597c47df7d834b8897a7))

* ci: ensure token for documentation ([`dde290f`](https://github.com/KennethEnevoldsen/asent/commit/dde290fdf9e3e95a4fca5a4612c2b372e67cd062))

* ci: Updated ci requirements ([`3a9473f`](https://github.com/KennethEnevoldsen/asent/commit/3a9473ff62e6937b25c21bbb09165cda2c8c574c))

* ci: fix pytest args ([`7e38eac`](https://github.com/KennethEnevoldsen/asent/commit/7e38eac5e03444039dc8094b69656c80bd5b5dec))

* ci: updated docs ci ([`3b0b23f`](https://github.com/KennethEnevoldsen/asent/commit/3b0b23ffa3407475818b228bd461d13698f8f52f))

* ci: Added requirements to test development ([`9af3aba`](https://github.com/KennethEnevoldsen/asent/commit/9af3abaf5b34edf1569d602f97a270a715aaa7fa))

* ci: Move to cruft template ([`14405e4`](https://github.com/KennethEnevoldsen/asent/commit/14405e47c9cfd903e1e81ff5a9c38af413225311))

* ci: update docs ci ([`bab750c`](https://github.com/KennethEnevoldsen/asent/commit/bab750c798de9bd5179063aa2f1792871888c54e))

### Documentation

* docs: removed badged from readme ([`95ba4c7`](https://github.com/KennethEnevoldsen/asent/commit/95ba4c7c525a173638a6de9de88477d77a890f61))

### Fix

* fix: Update dependencies to include pyright ([`f0d18b8`](https://github.com/KennethEnevoldsen/asent/commit/f0d18b8a8f65fec942baa916b852d70e01f853f8))

* fix: update types to match 3.9 ([`c1bf063`](https://github.com/KennethEnevoldsen/asent/commit/c1bf06317d35793da6f3cc7ab65916400de2b9bb))

* fix: ran static type checks ([`818b2a5`](https://github.com/KennethEnevoldsen/asent/commit/818b2a55bdb8be2294337990696da68c235a4b21))

* fix: Require 3.9 ([`6dd0f15`](https://github.com/KennethEnevoldsen/asent/commit/6dd0f15c9e2c93fbf855daa394527219e222aef0))

### Style

* style: applied new linter ([`7d778de`](https://github.com/KennethEnevoldsen/asent/commit/7d778deaf2be613e6d271005471228fd01a84c2b))

### Unknown

* rerun ci ([`27a5812`](https://github.com/KennethEnevoldsen/asent/commit/27a5812978d37a5c49b5df39cbe211a9f0fd2d31))

* rerun ci ([`39fb290`](https://github.com/KennethEnevoldsen/asent/commit/39fb29016ee54e2b034b6c5dd9f7502dd5d86bca))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent ([`b345c41`](https://github.com/KennethEnevoldsen/asent/commit/b345c41b8ea493315c7cacb1553251d3bfdddfd7))


## v0.7.5 (2023-09-04)

### Ci

* ci: Updated documentation ci ([`f24fde5`](https://github.com/KennethEnevoldsen/asent/commit/f24fde5e4163a82dcc5be1d4b694cac5fc80c8d5))

### Fix

* fix: error in pyproject.toml ([`4e76210`](https://github.com/KennethEnevoldsen/asent/commit/4e762104edcf3b41fe0c237fb1e0d2e5809e9dbf))

### Unknown

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent ([`1ad7008`](https://github.com/KennethEnevoldsen/asent/commit/1ad7008b226ca45c8c01d7acd90dc19388d6047e))


## v0.7.4 (2023-09-04)

### Fix

* fix: Added option ([`75932a8`](https://github.com/KennethEnevoldsen/asent/commit/75932a848902f656b79ff30f6a190feb09f4f1a2))

### Unknown

* Merge pull request #155 from KennethEnevoldsen/allow_filtering_viz

fix: Added option to filter viz ([`e8c64a7`](https://github.com/KennethEnevoldsen/asent/commit/e8c64a73a7d83908a854293133227e61d8cc2312))


## v0.7.3 (2023-09-04)

### Documentation

* docs: lock requirementns ([`bc09b92`](https://github.com/KennethEnevoldsen/asent/commit/bc09b924164a804a42c86f936f66f8ebd4186a24))

### Fix

* fix: update docs dependencies ([`dce2f58`](https://github.com/KennethEnevoldsen/asent/commit/dce2f58fa25c552314e7766438538db89867091c))

### Unknown

* Merge pull request #152 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`2a38b8d`](https://github.com/KennethEnevoldsen/asent/commit/2a38b8db72deb3e1804ff18d5e9fb8159ef07fce))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/astral-sh/ruff-pre-commit: v0.0.285 → v0.0.286](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.285...v0.0.286) ([`b035834`](https://github.com/KennethEnevoldsen/asent/commit/b03583442487170af46b627be635edc48996b5ee))

* Merge pull request #151 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`227bac7`](https://github.com/KennethEnevoldsen/asent/commit/227bac70c64c20cd2e69a0c1f5ccf55199e7746e))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/astral-sh/ruff-pre-commit: v0.0.284 → v0.0.285](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.284...v0.0.285) ([`1c1a92b`](https://github.com/KennethEnevoldsen/asent/commit/1c1a92bc90611b5ff1cc570f16217ccf2c81db7e))

* Merge pull request #150 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`76313c4`](https://github.com/KennethEnevoldsen/asent/commit/76313c49cd67114b41a71cde137d78cc14b324ff))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/astral-sh/ruff-pre-commit: v0.0.282 → v0.0.284](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.282...v0.0.284) ([`3847f62`](https://github.com/KennethEnevoldsen/asent/commit/3847f624da918b91eed54813663bf33f089bd7bf))


## v0.7.2 (2023-08-08)

### Build

* build: Removed upper bound on dev dependencies ([`05c1535`](https://github.com/KennethEnevoldsen/asent/commit/05c1535d067091ce85a65d92ae96173c8749d82c))

### Fix

* fix: Removed upper bound ([`499ad72`](https://github.com/KennethEnevoldsen/asent/commit/499ad72b3db2049d4a3dd633483f1b6b119f9729))

### Unknown

* Update release.yml ([`3550009`](https://github.com/KennethEnevoldsen/asent/commit/355000967ddbd5d74f9982748890237a04b281c1))

* Update release.yml ([`ce9608e`](https://github.com/KennethEnevoldsen/asent/commit/ce9608e696f32d507f6e02991fa3542fa3581645))

* Merge pull request #148 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`a0af9c5`](https://github.com/KennethEnevoldsen/asent/commit/a0af9c5763860b0fab070c77b1931006263e4b9f))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/astral-sh/ruff-pre-commit: v0.0.280 → v0.0.282](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.280...v0.0.282) ([`ec95beb`](https://github.com/KennethEnevoldsen/asent/commit/ec95beb1cc774639087446a04073e55ad561edde))

* Merge pull request #145 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`6910380`](https://github.com/KennethEnevoldsen/asent/commit/6910380a3bb7cd48a7edcdd953ebf1a154d9cc10))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/asottile/add-trailing-comma: v3.0.0 → v3.0.1](https://github.com/asottile/add-trailing-comma/compare/v3.0.0...v3.0.1) ([`df2ccae`](https://github.com/KennethEnevoldsen/asent/commit/df2ccae8378736b3f31c6b6794406a9a2f50977a))

* Merge pull request #144 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`d604f2f`](https://github.com/KennethEnevoldsen/asent/commit/d604f2fcf47ce243837f85a6a650afbc25b3f51c))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/astral-sh/ruff-pre-commit: v0.0.278 → v0.0.280](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.278...v0.0.280) ([`210c8a8`](https://github.com/KennethEnevoldsen/asent/commit/210c8a8cd1771c919de19a2db079af93f4a5f442))

* Merge pull request #143 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`392bb9d`](https://github.com/KennethEnevoldsen/asent/commit/392bb9d761d8c8aff20e8a4f74f0c09b7faa6c00))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.7.4 → v1.7.5](https://github.com/PyCQA/docformatter/compare/v1.7.4...v1.7.5)
- [github.com/psf/black: 23.3.0 → 23.7.0](https://github.com/psf/black/compare/23.3.0...23.7.0)
- [github.com/astral-sh/ruff-pre-commit: v0.0.277 → v0.0.278](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.277...v0.0.278) ([`f355454`](https://github.com/KennethEnevoldsen/asent/commit/f35545471f9f09f0d3b8a13da080ce18d086db44))

* Merge pull request #142 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`fc61cbf`](https://github.com/KennethEnevoldsen/asent/commit/fc61cbf34f65596e0d11caecabcb95c9c226aa50))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.7.3 → v1.7.4](https://github.com/PyCQA/docformatter/compare/v1.7.3...v1.7.4)
- https://github.com/charliermarsh/ruff-pre-commit → https://github.com/astral-sh/ruff-pre-commit
- [github.com/astral-sh/ruff-pre-commit: v0.0.275 → v0.0.277](https://github.com/astral-sh/ruff-pre-commit/compare/v0.0.275...v0.0.277) ([`e0990b5`](https://github.com/KennethEnevoldsen/asent/commit/e0990b588078a3ff8cb5f6599982d1a0f4982943))

* Merge pull request #141 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`45289c7`](https://github.com/KennethEnevoldsen/asent/commit/45289c713233324e9e7cc1da9f63f59499a5d3b4))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/asottile/add-trailing-comma: v2.5.1 → v3.0.0](https://github.com/asottile/add-trailing-comma/compare/v2.5.1...v3.0.0) ([`f543423`](https://github.com/KennethEnevoldsen/asent/commit/f543423f05c451b2b3aba1ee2a239bef6470070a))

* Merge pull request #140 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`2fd442f`](https://github.com/KennethEnevoldsen/asent/commit/2fd442f9e1a98991ff2761b991856f5de02118ff))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.7.2 → v1.7.3](https://github.com/PyCQA/docformatter/compare/v1.7.2...v1.7.3)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.272 → v0.0.275](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.272...v0.0.275) ([`68126af`](https://github.com/KennethEnevoldsen/asent/commit/68126afd7c10c01d4164adb17815bcc74402f403))

* Merge pull request #139 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`a1b8eda`](https://github.com/KennethEnevoldsen/asent/commit/a1b8eda9c0128f556214ac0890e4a5d52a624cc9))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/asottile/add-trailing-comma: v2.4.0 → v2.5.1](https://github.com/asottile/add-trailing-comma/compare/v2.4.0...v2.5.1)
- [github.com/PyCQA/docformatter: v1.7.1 → v1.7.2](https://github.com/PyCQA/docformatter/compare/v1.7.1...v1.7.2)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.270 → v0.0.272](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.270...v0.0.272) ([`2bbb387`](https://github.com/KennethEnevoldsen/asent/commit/2bbb38744771bd91092af174eedfccf30e51a544))

* Merge pull request #135 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`c7b980a`](https://github.com/KennethEnevoldsen/asent/commit/c7b980a638ef183b220b0b080a2404c65a8fa3ce))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.269 → v0.0.270](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.269...v0.0.270) ([`fba1c0a`](https://github.com/KennethEnevoldsen/asent/commit/fba1c0a96e0bf67e25f4e38b26364cf4a408f341))

* Merge pull request #134 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`e9c2ddc`](https://github.com/KennethEnevoldsen/asent/commit/e9c2ddcbbc79327eb235a7d9640833990d062c77))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.6.5 → v1.7.1](https://github.com/PyCQA/docformatter/compare/v1.6.5...v1.7.1)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.267 → v0.0.269](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.267...v0.0.269) ([`527157b`](https://github.com/KennethEnevoldsen/asent/commit/527157b372edf7871e807e41e63cc4a163926ffe))

* Merge pull request #132 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`a3b34d7`](https://github.com/KennethEnevoldsen/asent/commit/a3b34d7521d727821c5096c8b2f7d52eb84ee745))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.265 → v0.0.267](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.265...v0.0.267) ([`f0b1099`](https://github.com/KennethEnevoldsen/asent/commit/f0b1099c39fe8ae406140f1e9f7d5ce478cb8ae1))

* Merge pull request #131 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`d4ed05e`](https://github.com/KennethEnevoldsen/asent/commit/d4ed05eeab687d8d636dd43f1bd2aeb893db85a3))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.6.4 → v1.6.5](https://github.com/PyCQA/docformatter/compare/v1.6.4...v1.6.5)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.263 → v0.0.265](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.263...v0.0.265) ([`067d716`](https://github.com/KennethEnevoldsen/asent/commit/067d716795f9e388bfea211e7b3487185fcb2570))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent ([`02189ce`](https://github.com/KennethEnevoldsen/asent/commit/02189cea74664c256781ffcfb99558a15901a216))

* Merge pull request #123 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`8f3de4f`](https://github.com/KennethEnevoldsen/asent/commit/8f3de4f53e043dd9c7d3e9fa65c76a643aab83c2))

* [pre-commit.ci] auto fixes from pre-commit.com hooks

for more information, see https://pre-commit.ci ([`856ce97`](https://github.com/KennethEnevoldsen/asent/commit/856ce9767c0b623cd52459c11f4f2ccbbc2881df))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.6.3 → v1.6.4](https://github.com/PyCQA/docformatter/compare/v1.6.3...v1.6.4)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.262 → v0.0.263](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.262...v0.0.263) ([`24f3a42`](https://github.com/KennethEnevoldsen/asent/commit/24f3a424251c84dc3104f8fd09a20df2a2c2cc0b))

* Merge pull request #122 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`d608a3e`](https://github.com/KennethEnevoldsen/asent/commit/d608a3e569fc51b510c142ffdeb8fdbfe413d62c))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/docformatter: v1.5.1 → v1.6.3](https://github.com/PyCQA/docformatter/compare/v1.5.1...v1.6.3)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.260 → v0.0.262](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.260...v0.0.262) ([`6e0e779`](https://github.com/KennethEnevoldsen/asent/commit/6e0e779497e26e4c17d1fd03fbd831ddd44c04d7))

* Merge pull request #119 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`e0efce5`](https://github.com/KennethEnevoldsen/asent/commit/e0efce538e39b37414b9542a170430236dcc7efa))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/psf/black: 23.1.0 → 23.3.0](https://github.com/psf/black/compare/23.1.0...23.3.0)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.259 → v0.0.260](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.259...v0.0.260) ([`460b1f6`](https://github.com/KennethEnevoldsen/asent/commit/460b1f636a52c72f872589d35e44886ac5eb2b52))

* Merge pull request #113 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`9c9ac10`](https://github.com/KennethEnevoldsen/asent/commit/9c9ac1098634771020f9e6438b5c4a114e4902ac))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.257 → v0.0.259](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.257...v0.0.259) ([`3104009`](https://github.com/KennethEnevoldsen/asent/commit/310400955c2d0bd2bd0afabf9cfb489f0f8f0c2e))

* Merge pull request #112 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`ef5bd86`](https://github.com/KennethEnevoldsen/asent/commit/ef5bd86106291eb91cb1980dfc4c0a7dc62b9671))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.254 → v0.0.257](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.254...v0.0.257) ([`ee1c10c`](https://github.com/KennethEnevoldsen/asent/commit/ee1c10c53e9bd0a1a7f8e2eb5b257d2c66877b9a))


## v0.7.1 (2023-03-08)

### Build

* build: updated spacy dependency to 3.5 ([`ebfa424`](https://github.com/KennethEnevoldsen/asent/commit/ebfa424400331181efca1df4bc591d7c439f8ceb))

### Ci

* ci: fix coverage badge by installing package in editable mode ([`52da656`](https://github.com/KennethEnevoldsen/asent/commit/52da656af19e3c972afe07e7094a2f3dbc991549))

* ci: updated when cov. comment are created ([`edcd96a`](https://github.com/KennethEnevoldsen/asent/commit/edcd96a7f2382ea435b7a5dac9888f44cbc6d64b))

* ci: update depandabot to not update ci ([`ff44396`](https://github.com/KennethEnevoldsen/asent/commit/ff4439687b763427df568815f84751cad0a4d6d2))

### Documentation

* docs: fix badge ([`40a8d49`](https://github.com/KennethEnevoldsen/asent/commit/40a8d49731c5b2c100da1e64493a78bdeb7ea2e1))

### Fix

* fix: Updated spacy dependency ([`bfe8424`](https://github.com/KennethEnevoldsen/asent/commit/bfe842446028ecae62899a684f2099f75b8ed2ae))

### Unknown

* Merge pull request #111 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`57bd49a`](https://github.com/KennethEnevoldsen/asent/commit/57bd49ad9757d5e78f1c80d482cdc7a7206d1a75))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.252 → v0.0.254](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.252...v0.0.254) ([`e1bbdb7`](https://github.com/KennethEnevoldsen/asent/commit/e1bbdb74b3550073e8143b90692d75e9e1fc7204))

* Merge pull request #106 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`aefb8ce`](https://github.com/KennethEnevoldsen/asent/commit/aefb8cea0b891f89480cc81caed7ebd22285bdbc))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/charliermarsh/ruff-pre-commit: v0.0.248 → v0.0.252](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.248...v0.0.252) ([`5635aac`](https://github.com/KennethEnevoldsen/asent/commit/5635aacc900ed366deedbb111934c664da52aa15))

* Merge pull request #105 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`8401381`](https://github.com/KennethEnevoldsen/asent/commit/840138195317c8d0095513669621cf54b586af2a))

* [pre-commit.ci] auto fixes from pre-commit.com hooks

for more information, see https://pre-commit.ci ([`036b611`](https://github.com/KennethEnevoldsen/asent/commit/036b6115153b82bd75ae26e869494a30084137db))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/psf/black: 22.12.0 → 23.1.0](https://github.com/psf/black/compare/22.12.0...23.1.0)
- [github.com/charliermarsh/ruff-pre-commit: v0.0.239 → v0.0.248](https://github.com/charliermarsh/ruff-pre-commit/compare/v0.0.239...v0.0.248) ([`4bd152d`](https://github.com/KennethEnevoldsen/asent/commit/4bd152db47e3888805d60cf0fa0c17687ed53dd1))


## v0.7.0 (2023-02-08)

### Build

* build: Change python requirement ([`544fc9c`](https://github.com/KennethEnevoldsen/asent/commit/544fc9cb4d54fd2be27f709ca154e91b7b5b4f8d))

* build: change to src structure ([`89983ed`](https://github.com/KennethEnevoldsen/asent/commit/89983ed8b4ff24379e7d19cce6e513fa79002f24))

* build: updated build to use a pyproject.toml ([`2aa548c`](https://github.com/KennethEnevoldsen/asent/commit/2aa548c2f6fa0d9ce6b3f080c98aea4f9f6f863d))

* build: Relaxed version requirements ([`2ffb2d9`](https://github.com/KennethEnevoldsen/asent/commit/2ffb2d98cdc9658977370def60d3b1e24a950a79))

### Ci

* ci: Update python versions tested ([`51994d9`](https://github.com/KennethEnevoldsen/asent/commit/51994d984367555d30ffc55e31e62a9737723d4e))

* ci: fix semantic release ([`aacc0df`](https://github.com/KennethEnevoldsen/asent/commit/aacc0dfd344ce4bd69363ad7d849e0f5aa6f23eb))

* ci: removed pyupgrade from ci ([`c5bd7a0`](https://github.com/KennethEnevoldsen/asent/commit/c5bd7a02304a472c0a6078e03a94191326e54a26))

* ci: added stalebot ([`c90b005`](https://github.com/KennethEnevoldsen/asent/commit/c90b005154db5d536475468e804981cba00032e2))

* ci: added semantic release ([`4f38d42`](https://github.com/KennethEnevoldsen/asent/commit/4f38d4267671bae2f2c9c6716e9e27ae7672e49b))

* ci: updated tests workflow ([`5b60ec1`](https://github.com/KennethEnevoldsen/asent/commit/5b60ec144552cc7bea9ddd457be22d79e4f3bf1d))

* ci: Added stalebot ([`fec6545`](https://github.com/KennethEnevoldsen/asent/commit/fec65457a34296a27012b9a260ce35ad0a941e7e))

* ci: add dependabot ([`604c195`](https://github.com/KennethEnevoldsen/asent/commit/604c1956031441c47bd605f0d29a3e0617f4082a))

* ci: removed duplicate pre-commit ci ([`ff1a269`](https://github.com/KennethEnevoldsen/asent/commit/ff1a26937e0a1877508aeeb9e96827f7c67acb94))

* ci: replaced black ci with pre-commit ci ([`54552b4`](https://github.com/KennethEnevoldsen/asent/commit/54552b448dfe2ea665df79d71edf54f827dd2b38))

* ci: Added mypy and darglint ([`0b6f707`](https://github.com/KennethEnevoldsen/asent/commit/0b6f707f4fe72159e7b80d499c92649868ce8167))

* ci: remove pyupgrade from pre-commit hook ([`ac2c2c6`](https://github.com/KennethEnevoldsen/asent/commit/ac2c2c669674a48cbbc0fbcf3003d7c0114cb769))

### Documentation

* docs: update python req. badge ([`01e8cb6`](https://github.com/KennethEnevoldsen/asent/commit/01e8cb61a863732186c53b8b464bc1b1a5dbf149))

* docs: fixed version for tutorial req. ([`5e0a75b`](https://github.com/KennethEnevoldsen/asent/commit/5e0a75b0700572fb9fc63658ca7e0be2cebc8e8f))

* docs: fixed error in tutorials req. ([`da69d28`](https://github.com/KennethEnevoldsen/asent/commit/da69d283fdabe2635a4e8d4b1f1a59f62713d5c9))

* docs: updated documentation ([`52b6380`](https://github.com/KennethEnevoldsen/asent/commit/52b63809ff56dc376c8f74f518600170e698afac))

* docs: updated docs with new changes ([`11b21ce`](https://github.com/KennethEnevoldsen/asent/commit/11b21cefed4e3e0522e689ecd239524683f0a6f2))

* docs: Updated documentation ([`219a29f`](https://github.com/KennethEnevoldsen/asent/commit/219a29f814a1e0283f1022b2bee941ceba0f0d76))

* docs: updated example in readme ([`65a9de9`](https://github.com/KennethEnevoldsen/asent/commit/65a9de9023e7055b9a045e2e6de211000a217c7f))

### Feature

* feat: Added two additional intensifers for Danish ([`21f121d`](https://github.com/KennethEnevoldsen/asent/commit/21f121dafc406a2fb6e357b06fdac70a8d6f5f40))

* feat: Added two additional intensifiers for Danish ([`9a6351b`](https://github.com/KennethEnevoldsen/asent/commit/9a6351bee4b2a8c5f59991fe5439307b84f731bd))

### Fix

* fix: update prediciton visualiser handle overlapping spans ([`f68bb55`](https://github.com/KennethEnevoldsen/asent/commit/f68bb55206aa54a74147fd1734c941a2a140d653))

* fix: Sentence bounderies are now considered when check negations and intensifiers ([`4caa5a1`](https://github.com/KennethEnevoldsen/asent/commit/4caa5a1977fdea6f465e94a2fe52b1fdd51aa338))

### Style

* style: update pre-commit ([`9c7ad47`](https://github.com/KennethEnevoldsen/asent/commit/9c7ad4794f5f22ba256f2f5c9cca55624ebabdda))

* style: removed trailing whitespace ([`c555b5e`](https://github.com/KennethEnevoldsen/asent/commit/c555b5ecb5c6b663ded1d96288f5d8aa8819d906))

### Test

* test: Updated spacy pipelines for test ([`9b8f7a7`](https://github.com/KennethEnevoldsen/asent/commit/9b8f7a7bfee5ff2787765f713555774e891e4824))

### Unknown

* v0.6.1 ([`5727d34`](https://github.com/KennethEnevoldsen/asent/commit/5727d34e3cf89f81a539f25560c302187a877420))

* Merge pull request #90 from KennethEnevoldsen/ci-update

ci-update ([`e02dcb3`](https://github.com/KennethEnevoldsen/asent/commit/e02dcb36261b6e4a568ee0c3a4cb0d9c01c272de))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent into ci-update ([`52fb827`](https://github.com/KennethEnevoldsen/asent/commit/52fb827a2bd87059e02ec556a9565dbf52f4651c))

* v0.6.0 ([`00499e9`](https://github.com/KennethEnevoldsen/asent/commit/00499e9a5af8a7d01dc000f6d9b765a0484c110d))

* bumbed version id with latest version ([`19fe7c5`](https://github.com/KennethEnevoldsen/asent/commit/19fe7c545f0608ce3be0b6c3600c9c1e421f0695))

* Merge pull request #85 from alouca/patch-1

Use encoding UTF-8 when reading &#39;da&#39; CSV Files ([`4385099`](https://github.com/KennethEnevoldsen/asent/commit/438509937abf157f849ac8192413cec25e2d33c4))

* Use encoding UTF-8 when reading &#39;da&#39; CSV Files

Without explicitly specifying UTF-8, under certain circumstances it defaults to &#39;ascii&#39; breaking this. ([`b3dea6d`](https://github.com/KennethEnevoldsen/asent/commit/b3dea6d20fdeea05dbb390cd7a7568e78ca6a745))

* Merge pull request #81 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`453ed19`](https://github.com/KennethEnevoldsen/asent/commit/453ed19050611da368e45a6e1f4f2eb8709ad645))

* Merge pull request #84 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.42

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.41 to 1.1.42 ([`a2c9672`](https://github.com/KennethEnevoldsen/asent/commit/a2c96720321b541522abeefd9c7c4327c2832821))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.41 to 1.1.42

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.41 to 1.1.42.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Changelog](https://github.com/MishaKav/pytest-coverage-comment/blob/main/CHANGELOG.md)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.41...v1.1.42)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`fd74d01`](https://github.com/KennethEnevoldsen/asent/commit/fd74d01094efd13a73382f844844b24f5d7a37ac))

* [pre-commit.ci] auto fixes from pre-commit.com hooks

for more information, see https://pre-commit.ci ([`9be1561`](https://github.com/KennethEnevoldsen/asent/commit/9be1561053b9f652995d8bee860781342a72ff82))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/pycqa/isort: 5.10.1 → 5.11.4](https://github.com/pycqa/isort/compare/5.10.1...5.11.4)
- [github.com/asottile/add-trailing-comma: v2.3.0 → v2.4.0](https://github.com/asottile/add-trailing-comma/compare/v2.3.0...v2.4.0)
- [github.com/PyCQA/docformatter: v1.5.0 → v1.5.1](https://github.com/PyCQA/docformatter/compare/v1.5.0...v1.5.1) ([`2038031`](https://github.com/KennethEnevoldsen/asent/commit/203803192d5cd67d66ba889f74c3e17cface271f))

* Merge pull request #82 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.41 ([`8ff0b6f`](https://github.com/KennethEnevoldsen/asent/commit/8ff0b6f7864d0b575f7610e585979c1e83b6195f))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.40 to 1.1.41

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.40 to 1.1.41.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Changelog](https://github.com/MishaKav/pytest-coverage-comment/blob/main/CHANGELOG.md)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.40...v1.1.41)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`26fad22`](https://github.com/KennethEnevoldsen/asent/commit/26fad22662bd022662ec6a3a83f7052e9d46ba5b))

* Merge pull request #80 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`11e5a34`](https://github.com/KennethEnevoldsen/asent/commit/11e5a340c6338257245fcf7f79ee31335af1e41d))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/psf/black: 22.10.0 → 22.12.0](https://github.com/psf/black/compare/22.10.0...22.12.0) ([`6063ae3`](https://github.com/KennethEnevoldsen/asent/commit/6063ae3c73d6393501cd598c0c680e03d319d380))

* Update documentation.yml ([`ee52388`](https://github.com/KennethEnevoldsen/asent/commit/ee523889d372639bdcbf4b70c93f7f0ba8bcf8a0))

* Merge pull request #78 from KennethEnevoldsen/dependabot/github_actions/sphinx-notes/pages-3

:arrow_up: Bump sphinx-notes/pages from 2 to 3 ([`a7d62ea`](https://github.com/KennethEnevoldsen/asent/commit/a7d62eae9dab41325f1d0b463ee603e609e2b442))

* :arrow_up: Bump sphinx-notes/pages from 2 to 3

Bumps [sphinx-notes/pages](https://github.com/sphinx-notes/pages) from 2 to 3.
- [Release notes](https://github.com/sphinx-notes/pages/releases)
- [Commits](https://github.com/sphinx-notes/pages/compare/v2...v3)

---
updated-dependencies:
- dependency-name: sphinx-notes/pages
  dependency-type: direct:production
  update-type: version-update:semver-major
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`a5776bc`](https://github.com/KennethEnevoldsen/asent/commit/a5776bc2aade2d013767aa96994b34a413dcf791))

* Merge pull request #77 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.40

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.39 to 1.1.40 ([`617b7d5`](https://github.com/KennethEnevoldsen/asent/commit/617b7d5b34e13bb2a96baec2496c00c17873eaa0))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.39 to 1.1.40

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.39 to 1.1.40.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Changelog](https://github.com/MishaKav/pytest-coverage-comment/blob/main/CHANGELOG.md)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.39...v1.1.40)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`8fed892`](https://github.com/KennethEnevoldsen/asent/commit/8fed89293f0efbf35f1eb2bdc1e3162381dfef7f))

* Merge pull request #76 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.39

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.37 to 1.1.39 ([`0fb7adc`](https://github.com/KennethEnevoldsen/asent/commit/0fb7adccc714a0fab0ab86995d93b959f39db3b3))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.37 to 1.1.39

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.37 to 1.1.39.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Changelog](https://github.com/MishaKav/pytest-coverage-comment/blob/main/CHANGELOG.md)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.37...v1.1.39)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`c931c00`](https://github.com/KennethEnevoldsen/asent/commit/c931c00b806080193ff5e5e4f6fccc6a042cfc57))

* Merge pull request #75 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`bfd8f91`](https://github.com/KennethEnevoldsen/asent/commit/bfd8f9123c19724274cdfb7d286762cb80b90469))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/PyCQA/flake8: 5.0.4 → 6.0.0](https://github.com/PyCQA/flake8/compare/5.0.4...6.0.0) ([`2f6704b`](https://github.com/KennethEnevoldsen/asent/commit/2f6704bd73d72a90055b8ff1f7dad8af7abd3baf))

* Update LICENSE ([`26c9de3`](https://github.com/KennethEnevoldsen/asent/commit/26c9de3bcc398d63e3894a3d6550dddb8cc65d2c))

* Merge pull request #74 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`e087385`](https://github.com/KennethEnevoldsen/asent/commit/e087385be7974d023f66debfe90958892d775686))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/pre-commit/mirrors-mypy: v0.990 → v0.991](https://github.com/pre-commit/mirrors-mypy/compare/v0.990...v0.991) ([`685c049`](https://github.com/KennethEnevoldsen/asent/commit/685c049785b9b98e911c6b83f39b3184ce200f37))

* Merge pull request #73 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`c29c0c8`](https://github.com/KennethEnevoldsen/asent/commit/c29c0c8547c26fc3352bdd42a2ef86930e0bb8a6))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/pre-commit/mirrors-mypy: v0.982 → v0.990](https://github.com/pre-commit/mirrors-mypy/compare/v0.982...v0.990) ([`f534862`](https://github.com/KennethEnevoldsen/asent/commit/f5348623907b123c9272cbe5faee927d773a496f))

* Merge pull request #72 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.37

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.36 to 1.1.37 ([`04af49a`](https://github.com/KennethEnevoldsen/asent/commit/04af49a73c65b32bc7cddbbadd1b8bd1bf75dba6))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.36 to 1.1.37

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.36 to 1.1.37.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Changelog](https://github.com/MishaKav/pytest-coverage-comment/blob/main/CHANGELOG.md)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.36...v1.1.37)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`04b4dd1`](https://github.com/KennethEnevoldsen/asent/commit/04b4dd1f9742723b037e8cbce3427167e454802a))

* Merge pull request #71 from KennethEnevoldsen/dependabot/github_actions/schneegans/dynamic-badges-action-1.6.0 ([`8f353e0`](https://github.com/KennethEnevoldsen/asent/commit/8f353e0f5fc962008065217f783beeecf684c77f))

* :arrow_up: Bump schneegans/dynamic-badges-action from 1.5.0 to 1.6.0

Bumps [schneegans/dynamic-badges-action](https://github.com/schneegans/dynamic-badges-action) from 1.5.0 to 1.6.0.
- [Release notes](https://github.com/schneegans/dynamic-badges-action/releases)
- [Changelog](https://github.com/Schneegans/dynamic-badges-action/blob/master/changelog.md)
- [Commits](https://github.com/schneegans/dynamic-badges-action/compare/v1.5.0...v1.6.0)

---
updated-dependencies:
- dependency-name: schneegans/dynamic-badges-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`7438be9`](https://github.com/KennethEnevoldsen/asent/commit/7438be91f85e34a707175529a1429987d815b845))

* Merge pull request #70 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.36

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.35 to 1.1.36 ([`2a36e13`](https://github.com/KennethEnevoldsen/asent/commit/2a36e139f39bee47023a8ce82b3bdf9c9697fe69))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.35 to 1.1.36

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.35 to 1.1.36.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.35...v1.1.36)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`bea04de`](https://github.com/KennethEnevoldsen/asent/commit/bea04de50af67c7b8f4b259bc4608f72e2174577))

* Merge pull request #69 from KennethEnevoldsen/dependabot/github_actions/schneegans/dynamic-badges-action-1.5.0

:arrow_up: Bump schneegans/dynamic-badges-action from 1.3.0 to 1.5.0 ([`1227b54`](https://github.com/KennethEnevoldsen/asent/commit/1227b54d7993e07a6e5b175a0dfdd4b02a0389ee))

* Merge pull request #68 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`8ea81cc`](https://github.com/KennethEnevoldsen/asent/commit/8ea81cc9461bc40e8dc9d1045b7dd3e5253f19ee))

* :arrow_up: Bump schneegans/dynamic-badges-action from 1.3.0 to 1.5.0

Bumps [schneegans/dynamic-badges-action](https://github.com/schneegans/dynamic-badges-action) from 1.3.0 to 1.5.0.
- [Release notes](https://github.com/schneegans/dynamic-badges-action/releases)
- [Changelog](https://github.com/Schneegans/dynamic-badges-action/blob/master/changelog.md)
- [Commits](https://github.com/schneegans/dynamic-badges-action/compare/v1.3.0...v1.5.0)

---
updated-dependencies:
- dependency-name: schneegans/dynamic-badges-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f455736`](https://github.com/KennethEnevoldsen/asent/commit/f45573617d7dcbe4d3642f3eab3d828686830484))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/psf/black: 22.8.0 → 22.10.0](https://github.com/psf/black/compare/22.8.0...22.10.0)
- [github.com/pre-commit/mirrors-mypy: v0.981 → v0.982](https://github.com/pre-commit/mirrors-mypy/compare/v0.981...v0.982) ([`886c515`](https://github.com/KennethEnevoldsen/asent/commit/886c515b939448f44e8c4968dc18472d89d0e532))

* Merge pull request #67 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`3c489f6`](https://github.com/KennethEnevoldsen/asent/commit/3c489f6382484b383afcfb14f0e68aa21388bfac))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/pre-commit/mirrors-mypy: v0.971 → v0.981](https://github.com/pre-commit/mirrors-mypy/compare/v0.971...v0.981) ([`c2e07aa`](https://github.com/KennethEnevoldsen/asent/commit/c2e07aa5312787dbc54f94610b74702fd95c4d91))

* Merge pull request #66 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`dec90fb`](https://github.com/KennethEnevoldsen/asent/commit/dec90fbbb6e702b7fe167742c551a458e5514efb))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/asottile/add-trailing-comma: v2.2.3 → v2.3.0](https://github.com/asottile/add-trailing-comma/compare/v2.2.3...v2.3.0) ([`c2800b1`](https://github.com/KennethEnevoldsen/asent/commit/c2800b13e2ee059bf016756156f4aef0690b99f4))

* Merge pull request #65 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`edcdfcf`](https://github.com/KennethEnevoldsen/asent/commit/edcdfcf3c6bea89c0fdb85ea12bd30b53159fb2f))

* [pre-commit.ci] pre-commit autoupdate

updates:
- https://github.com/myint/docformatter → https://github.com/PyCQA/docformatter ([`6bcd8f5`](https://github.com/KennethEnevoldsen/asent/commit/6bcd8f5a72b1237300e4b1f17d7b73d80c40f1c7))

* Merge pull request #64 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.35

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.33 to 1.1.35 ([`4cb6732`](https://github.com/KennethEnevoldsen/asent/commit/4cb6732ddc471c4dd4eafc56ea2b1c050545a88e))

* Update pytest-cov-comment.yml ([`e34095d`](https://github.com/KennethEnevoldsen/asent/commit/e34095d1e236fb3cfc170b58634475522eeb9706))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.33 to 1.1.35

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.33 to 1.1.35.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.33...v1.1.35)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`8a8033c`](https://github.com/KennethEnevoldsen/asent/commit/8a8033c89a0adb9edce7ab3c286b055799e0d28d))

* Merge pull request #63 from KennethEnevoldsen/pre-commit-ci-update-config

[pre-commit.ci] pre-commit autoupdate ([`3e1af40`](https://github.com/KennethEnevoldsen/asent/commit/3e1af40eea027ba4833bfb5232dd97a11773efd0))

* [pre-commit.ci] auto fixes from pre-commit.com hooks

for more information, see https://pre-commit.ci ([`9c14c49`](https://github.com/KennethEnevoldsen/asent/commit/9c14c4968674da667d0736b6069862ff5b4bec78))

* [pre-commit.ci] pre-commit autoupdate

updates:
- [github.com/myint/docformatter: v1.3.1 → v1.5.0](https://github.com/myint/docformatter/compare/v1.3.1...v1.5.0)
- [github.com/psf/black: 22.3.0 → 22.8.0](https://github.com/psf/black/compare/22.3.0...22.8.0)
- [github.com/PyCQA/flake8: 4.0.1 → 5.0.4](https://github.com/PyCQA/flake8/compare/4.0.1...5.0.4)
- [github.com/pre-commit/mirrors-mypy: v0.961 → v0.971](https://github.com/pre-commit/mirrors-mypy/compare/v0.961...v0.971) ([`df296d1`](https://github.com/KennethEnevoldsen/asent/commit/df296d1ba772a26a1c1cbed273fb87680a30cd4c))

* Merge pull request #61 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.33

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.32 to 1.1.33 ([`c716930`](https://github.com/KennethEnevoldsen/asent/commit/c71693031da4cd40ef1d780dbb16c3023f5dc462))

* Update pytest-cov-comment.yml ([`daff21b`](https://github.com/KennethEnevoldsen/asent/commit/daff21b1ff07c053d59e0abb4a6100cc7af80999))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.32 to 1.1.33

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.32 to 1.1.33.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.32...v1.1.33)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f9d9d24`](https://github.com/KennethEnevoldsen/asent/commit/f9d9d24b788ef6889d1ab7dc6b921e78e34725a4))

* Merge pull request #60 from KennethEnevoldsen/KennethEnevoldsen/issue-Add-prediction-detailed-visualiser-to-asent-using-the-span-visualiser

KennethEnevoldsen/issue-Add-prediction-detailed-visualiser-to-asent-using-the-span-visualiser ([`70b10ef`](https://github.com/KennethEnevoldsen/asent/commit/70b10efa2c304cc5649181bc486cdadaadd3c67d))

* tests: Updated pipeline for tutorials ([`956acde`](https://github.com/KennethEnevoldsen/asent/commit/956acde5990ad1a652d370ebd52b7d884667f0ac))

* Merge pull request #59 from KennethEnevoldsen/bug_inclusion_of_info_out_of_span

Fixes #58. Negations and intensifiers are now no longer considered outside of the sentence span. ([`70ccaaf`](https://github.com/KennethEnevoldsen/asent/commit/70ccaaf70ba19b0174665a3cb1a20126db975b3f))

* Merge pull request #56 from tomaarsen/docs/intro_error

Resolved issue with overwriting `nlp` in the introduction doc page ([`ff97e73`](https://github.com/KennethEnevoldsen/asent/commit/ff97e73b3fc5320a2492a7a7d74040019d3aefc4))

* Resolved issue with overwriting
lp in the introduction doc page ([`f424d17`](https://github.com/KennethEnevoldsen/asent/commit/f424d1744329a46c352c2be93c16d09d3c33ccd9))

* Merge pull request #54 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.32

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.29 to 1.1.32 ([`b93016f`](https://github.com/KennethEnevoldsen/asent/commit/b93016f744095dcc4e3ea11e19f93c6833a0b0f5))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.29 to 1.1.32

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.29 to 1.1.32.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.29...v1.1.32)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`f080196`](https://github.com/KennethEnevoldsen/asent/commit/f0801968f82d0a82e70f1def7c7f736115def695))

* Merge pull request #49 from KennethEnevoldsen/dependabot/pip/spacy-gte-3.0.0-and-lt-3.5.0

:arrow_up: Update spacy requirement from &lt;3.4.0,&gt;=3.0.0 to &gt;=3.0.0,&lt;3.5.0 ([`548f460`](https://github.com/KennethEnevoldsen/asent/commit/548f460dc2b474b7aff1e088b736ea8177c386ee))

* :arrow_up: Update spacy requirement

Updates the requirements on [spacy](https://github.com/explosion/spaCy) to permit the latest version.
- [Release notes](https://github.com/explosion/spaCy/releases)
- [Commits](https://github.com/explosion/spaCy/compare/v3.0.0...v3.4.0)

---
updated-dependencies:
- dependency-name: spacy
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`03601d8`](https://github.com/KennethEnevoldsen/asent/commit/03601d87d06225eb75644a4dc416f705339c8171))

* fixed spelling errors in readme. ([`4447831`](https://github.com/KennethEnevoldsen/asent/commit/4447831748d682664def1d71b85c15af62cb8efa))

* updatred readme ([`eeef9f1`](https://github.com/KennethEnevoldsen/asent/commit/eeef9f10e077ebff19ff10615ffa5ee7b3082652))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent into main ([`e49bc10`](https://github.com/KennethEnevoldsen/asent/commit/e49bc10cc0e4d3f9e72be0ac7aa55096804c8e12))

* updated tests ([`4ec0729`](https://github.com/KennethEnevoldsen/asent/commit/4ec0729d936e1499a13b23874a4f94ddcb92a3f1))

* Merge pull request #48 from KennethEnevoldsen/feature/new_languages

Feature/new languages ([`bec1d99`](https://github.com/KennethEnevoldsen/asent/commit/bec1d996d2aa7c7347fca596abcd2928e0cdf505))

* Merge branch &#39;main&#39; into feature/new_languages ([`2c7115d`](https://github.com/KennethEnevoldsen/asent/commit/2c7115d22629e9bcc9941337955fb981c7b38631))

* updated readme ([`6b9ee4d`](https://github.com/KennethEnevoldsen/asent/commit/6b9ee4dd4db4ce995bbe9373110eed9f7764bf89))

* fixed missing language in tests ([`46b858b`](https://github.com/KennethEnevoldsen/asent/commit/46b858bdbf397780e64270892e53557bcf9a587a))

* Update README.md ([`715f2de`](https://github.com/KennethEnevoldsen/asent/commit/715f2ded01dfa98546f926e056fa6eaf63c42c95))

* Merge pull request #47 from KennethEnevoldsen/feature/new_languages

Feature/new languages ([`89d0386`](https://github.com/KennethEnevoldsen/asent/commit/89d03866847c0e9b6e7477b6b6aa33efaf6350ff))

* Added description to readme ([`3bcd3c1`](https://github.com/KennethEnevoldsen/asent/commit/3bcd3c13c5a05cf0550bf217fd255d78907b97a2))

* added esperanto ([`62c4e07`](https://github.com/KennethEnevoldsen/asent/commit/62c4e074bf7e46012045c2e53e15c7de0a6fb83b))

* Merge pull request #46 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.29

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.28 to 1.1.29 ([`1ba1c44`](https://github.com/KennethEnevoldsen/asent/commit/1ba1c44823311a7ec2f7b2ccae5f3385c5b2fa74))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.28 to 1.1.29

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.28 to 1.1.29.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.28...v1.1.29)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`8aa068d`](https://github.com/KennethEnevoldsen/asent/commit/8aa068d5e06e6a0596a2523ae3065ae8bb6f4744))

* Added documentation for new languages ([`2b2ce4d`](https://github.com/KennethEnevoldsen/asent/commit/2b2ce4dff4136930c1e592da475765afbfff16dd))

* changed word rating seperator ([`5f3b2f1`](https://github.com/KennethEnevoldsen/asent/commit/5f3b2f18a56abbb03da7b6ed00ed9fa7dc020da3))

* added test for german ([`d22d642`](https://github.com/KennethEnevoldsen/asent/commit/d22d6424504ac17bec67c67050c52a00972e0d72))

* changed word rating seperator ([`4b0a32d`](https://github.com/KennethEnevoldsen/asent/commit/4b0a32d3d274e766eec48012acbb2bbc46b0202d))

* removed mypy ([`c9b98cd`](https://github.com/KennethEnevoldsen/asent/commit/c9b98cd90256f69c969ee5e73b6bd54921bfb835))

* added autoconstructed language lexicons along with tests ([`d4af4bf`](https://github.com/KennethEnevoldsen/asent/commit/d4af4bfc06e3c1ac8bf8826af49c253f5d69059d))

* rixed errors in paths ([`9f356cb`](https://github.com/KennethEnevoldsen/asent/commit/9f356cb7eb6800b1e06313dada7310fc84b5fa17))

* removed autogenerated lexicons from def. lang ([`bbbdf68`](https://github.com/KennethEnevoldsen/asent/commit/bbbdf682977e281442c7850755fb59001a4fc03b))

* added code for creating new language lexicons ([`531cc67`](https://github.com/KennethEnevoldsen/asent/commit/531cc67efd71f948b9b14a3f44af55b2c3b372c5))

* simplified existing codebase ([`2ce82d3`](https://github.com/KennethEnevoldsen/asent/commit/2ce82d34366f633162c8a4ee1ed9d329747b7963))

* added Chen Skiena lexicons ([`ac00072`](https://github.com/KennethEnevoldsen/asent/commit/ac00072fcf896854667dbe8c1c0db738b909f8ea))

* moved citation from readme to .cff ([`5911675`](https://github.com/KennethEnevoldsen/asent/commit/5911675d86be73d3da4e845c9e4d5e6478234ca0))

* Merge branch &#39;main&#39; of https://github.com/KennethEnevoldsen/asent into main ([`5d25f9c`](https://github.com/KennethEnevoldsen/asent/commit/5d25f9c7a59cf25e427ca333446371106e6234b7))

* updated documentation ([`48bb78f`](https://github.com/KennethEnevoldsen/asent/commit/48bb78f3e09e85f974e39b34d6370f60daee2f2d))

* fixing versions for documentation ([`d6dd042`](https://github.com/KennethEnevoldsen/asent/commit/d6dd04259ced826d266b062d324ed8b2dd6194b0))

* Update requirements.txt ([`278529e`](https://github.com/KennethEnevoldsen/asent/commit/278529e6e8ffab727e4332f6284113239b7a8ccf))

* Merge pull request #43 from KennethEnevoldsen/update_workflows

Updated workflows ([`746bab3`](https://github.com/KennethEnevoldsen/asent/commit/746bab35fd4d5ac86f5f31e2ec220fe1ae55b63e))

* remove unused file ([`18256be`](https://github.com/KennethEnevoldsen/asent/commit/18256bece982826fda44359affb3ec6488f06a1f))

* fixed list typing ([`c434b6f`](https://github.com/KennethEnevoldsen/asent/commit/c434b6f76297082d471b5e3fe4dd5997cef6408c))

* fixed type ([`a7a78a7`](https://github.com/KennethEnevoldsen/asent/commit/a7a78a7e66df9293d7371ea81e529fcddc9c26e9))

* fixed manifest.in name ([`4a1a32f`](https://github.com/KennethEnevoldsen/asent/commit/4a1a32f8e1d4bc609219ee43c68ee5ccf5d5ec7e))

* fixed typing ([`7417081`](https://github.com/KennethEnevoldsen/asent/commit/74170813378c824bf7257e92cf8debd800c85a06))

* updated typing ([`fa2af93`](https://github.com/KennethEnevoldsen/asent/commit/fa2af93d4f24a5c38bf95b224d659ed1961e567c))

* Merge pull request #39 from KennethEnevoldsen/dependabot/pip/sphinx-gte-4.5.0-and-lt-6.0.0

:arrow_up: Update sphinx requirement from &lt;5.0.0,&gt;=4.5.0 to &gt;=4.5.0,&lt;6.0.0 ([`2492b15`](https://github.com/KennethEnevoldsen/asent/commit/2492b156a2799cbe472ab641460a427de2c20972))

* Merge branch &#39;main&#39; into dependabot/pip/sphinx-gte-4.5.0-and-lt-6.0.0 ([`9a08166`](https://github.com/KennethEnevoldsen/asent/commit/9a081667c4cbbf3e6623ae3b2825a8fefaaea4ba))

* Merge pull request #41 from KennethEnevoldsen/dependabot/pip/furo-2022.6.21

:arrow_up: Bump furo from 2022.4.7 to 2022.6.21 ([`e39a2cb`](https://github.com/KennethEnevoldsen/asent/commit/e39a2cb70b890cf8a7afadd99c4808cf2b6d48f0))

* fixed runtime typing ([`cb392ae`](https://github.com/KennethEnevoldsen/asent/commit/cb392aeb8a3e86fa4d9ef3baf7ea4b5fc72fb069))

* fixed typing ([`c371661`](https://github.com/KennethEnevoldsen/asent/commit/c3716619e51ad0f613b8c8f11ff386992fd30955))

* updated news ([`52866f2`](https://github.com/KennethEnevoldsen/asent/commit/52866f2ee60404037414e5976f06e35adef46a79))

* update faq ([`1354042`](https://github.com/KennethEnevoldsen/asent/commit/135404246bc47dd09337d5b5c2045b9d1c3c535a))

* ran pre-commit hooks on all files ([`d18f8fa`](https://github.com/KennethEnevoldsen/asent/commit/d18f8fac1de7c788d6b4ad52f2dc59480a7f97df))

* ran pre-commit on all files ([`7298e5b`](https://github.com/KennethEnevoldsen/asent/commit/7298e5bb2c0694c29a78abbb0a56880d256afa8b))

* fixed error in requirements ([`01e5652`](https://github.com/KennethEnevoldsen/asent/commit/01e5652749f41b346554373a43cfd0577bec2224))

* added citation.cff ([`45a078a`](https://github.com/KennethEnevoldsen/asent/commit/45a078aa8d349538940505a9d81a6b24ae83807f))

* added dependabot ([`d8997e5`](https://github.com/KennethEnevoldsen/asent/commit/d8997e5e2a439820c7054100b176d468a84f7438))

* fixed spacy pipelines ([`94777a0`](https://github.com/KennethEnevoldsen/asent/commit/94777a0c74a95c1104ae3619e4361597fda20c97))

* Merge pull request #42 from KennethEnevoldsen/minor_update

Minor update ([`99d6b58`](https://github.com/KennethEnevoldsen/asent/commit/99d6b58d235633d849eef3dac610a1fe18faea11))

* formatted to black ([`bbbc31e`](https://github.com/KennethEnevoldsen/asent/commit/bbbc31eb63fcc584e6ff0dbb1252017890854d36))

* added lexicons to manifest ([`0e42453`](https://github.com/KennethEnevoldsen/asent/commit/0e424534e1b32b6f9c148cb0259cb19be56d0668))

* ran tests ([`aad004b`](https://github.com/KennethEnevoldsen/asent/commit/aad004baa840f8c978caf22937f5d425cf295145))

* bumped version id ([`aff8054`](https://github.com/KennethEnevoldsen/asent/commit/aff8054e9c0a722de1a4f75f35ed33f8b0c860c3))

* moved tests out of package install ([`3e89fdd`](https://github.com/KennethEnevoldsen/asent/commit/3e89fdd7edad095fca45b596f6beb235fe5249ae))

* fixed path ([`3131d68`](https://github.com/KennethEnevoldsen/asent/commit/3131d686a9bf7fbe02d5be0618dec4707ba437f8))

* converted afinn to default ([`1d7ce28`](https://github.com/KennethEnevoldsen/asent/commit/1d7ce288aa9347f206ed473cbf2edd66dcea911f))

* Added common utils ([`7b5ce29`](https://github.com/KennethEnevoldsen/asent/commit/7b5ce297e971f2280f2a869d76729a037fbbdcef))

* merged gitignore ([`46c19f3`](https://github.com/KennethEnevoldsen/asent/commit/46c19f3d75320a132843a66b875b3d4083d030d3))

* :arrow_up: Bump furo from 2022.4.7 to 2022.6.21

Bumps [furo](https://github.com/pradyunsg/furo) from 2022.4.7 to 2022.6.21.
- [Release notes](https://github.com/pradyunsg/furo/releases)
- [Changelog](https://github.com/pradyunsg/furo/blob/main/docs/changelog.md)
- [Commits](https://github.com/pradyunsg/furo/compare/2022.04.07...2022.06.21)

---
updated-dependencies:
- dependency-name: furo
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`0b11d8f`](https://github.com/KennethEnevoldsen/asent/commit/0b11d8f01810b15520efd683ac1f60836b12f760))

* :arrow_up: Update sphinx requirement

Updates the requirements on [sphinx](https://github.com/sphinx-doc/sphinx) to permit the latest version.
- [Release notes](https://github.com/sphinx-doc/sphinx/releases)
- [Changelog](https://github.com/sphinx-doc/sphinx/blob/5.x/CHANGES)
- [Commits](https://github.com/sphinx-doc/sphinx/compare/v4.5.0...v5.0.1)

---
updated-dependencies:
- dependency-name: sphinx
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`e390b38`](https://github.com/KennethEnevoldsen/asent/commit/e390b38ec9eda376c08dc0850a8d45fa828b2c35))

* Merge pull request #38 from KennethEnevoldsen/fix-docs

fix-docs ([`6873cb9`](https://github.com/KennethEnevoldsen/asent/commit/6873cb902a790a2aff5d3645a6f95aa4a7a91665))

* Update requirements.txt ([`4036f7a`](https://github.com/KennethEnevoldsen/asent/commit/4036f7a17ad2ab4eacc94b71984bcbb968d4c1c2))

* Delete requirements.txt ([`1c1d0de`](https://github.com/KennethEnevoldsen/asent/commit/1c1d0deab5bc9ac3d53ab0d2192f23dd3d43e71d))

* fix-docs ([`3bfd1c8`](https://github.com/KennethEnevoldsen/asent/commit/3bfd1c88294656144a7ce643bbbee3916bc84b39))

* Merge pull request #37 from KennethEnevoldsen/dependabot/github_actions/actions/setup-python-4

:arrow_up: Bump actions/setup-python from 3 to 4 ([`c6d8ab6`](https://github.com/KennethEnevoldsen/asent/commit/c6d8ab62b12d7a4adf0b68e93de03611fd1c80fa))

* :arrow_up: Bump actions/setup-python from 3 to 4

Bumps [actions/setup-python](https://github.com/actions/setup-python) from 3 to 4.
- [Release notes](https://github.com/actions/setup-python/releases)
- [Commits](https://github.com/actions/setup-python/compare/v3...v4)

---
updated-dependencies:
- dependency-name: actions/setup-python
  dependency-type: direct:production
  update-type: version-update:semver-major
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`bf4b98a`](https://github.com/KennethEnevoldsen/asent/commit/bf4b98ace05477fd3210bb5944663ce0310a8518))

* Merge pull request #35 from KennethEnevoldsen/dependabot/pip/spacy-gte-3.0.0-and-lt-3.4.0

:arrow_up: Update spacy requirement from &lt;3.3.0,&gt;=3.0.0 to &gt;=3.0.0,&lt;3.4.0 ([`675f3dc`](https://github.com/KennethEnevoldsen/asent/commit/675f3dc414b73939b3f0d1cf175e0a685c628d02))

* Merge pull request #34 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.28

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.25 to 1.1.28 ([`6693696`](https://github.com/KennethEnevoldsen/asent/commit/669369672a984a74f29031cce7e2f4271c7009da))

* Update pytest-cov-comment.yml ([`ecf17f8`](https://github.com/KennethEnevoldsen/asent/commit/ecf17f894939812e6dbf97e7017ed2aa0dcc0e17))

* :arrow_up: Update spacy requirement

Updates the requirements on [spacy](https://github.com/explosion/spaCy) to permit the latest version.
- [Release notes](https://github.com/explosion/spaCy/releases)
- [Commits](https://github.com/explosion/spaCy/compare/v3.0.0...v3.3.0)

---
updated-dependencies:
- dependency-name: spacy
  dependency-type: direct:production
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`a851e1c`](https://github.com/KennethEnevoldsen/asent/commit/a851e1c91f53a52d2adcdbcf7067feb40c0b8190))

* Update pytest-cov-comment.yml ([`58dfb1b`](https://github.com/KennethEnevoldsen/asent/commit/58dfb1b01ae6c3926a0660a6c74263cc269a1311))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.25 to 1.1.28

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.25 to 1.1.28.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.25...v1.1.28)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`b818210`](https://github.com/KennethEnevoldsen/asent/commit/b818210c73c23a768c3cd26ce1156cd08fbd3e9f))

* Merge pull request #32 from KennethEnevoldsen/visualize-

Updated analysis visualisation ([`afbfebe`](https://github.com/KennethEnevoldsen/asent/commit/afbfebef6477b5143bd9183839e7c0e7d0640999))

* Merge pull request #31 from KennethEnevoldsen/dependabot/github_actions/schneegans/dynamic-badges-action-1.3.0

:arrow_up: Bump schneegans/dynamic-badges-action from 1.2.0 to 1.3.0 ([`6d4ce97`](https://github.com/KennethEnevoldsen/asent/commit/6d4ce97536996022564b55e6d3e2cb4a2203ac80))

* bumped version ([`f490df4`](https://github.com/KennethEnevoldsen/asent/commit/f490df48089621897bbf094f7387c3bac039cbbf))

* fixed images ([`5c7ad45`](https://github.com/KennethEnevoldsen/asent/commit/5c7ad45020610c22e11cf111cf31afde2a712083))

* set force to True as default ([`d95bdde`](https://github.com/KennethEnevoldsen/asent/commit/d95bddee0a9e96911c241f72798eb680a249fddc))

* fixed negation ([`a391e3a`](https://github.com/KennethEnevoldsen/asent/commit/a391e3a25129ecfa8598b83305212529f80be98b))

* Update pytest-cov-comment.yml ([`2a2e15a`](https://github.com/KennethEnevoldsen/asent/commit/2a2e15ad32f1d531ace80c0600c7a2c7b10dbe30))

* :arrow_up: Bump schneegans/dynamic-badges-action from 1.2.0 to 1.3.0

Bumps [schneegans/dynamic-badges-action](https://github.com/schneegans/dynamic-badges-action) from 1.2.0 to 1.3.0.
- [Release notes](https://github.com/schneegans/dynamic-badges-action/releases)
- [Changelog](https://github.com/Schneegans/dynamic-badges-action/blob/master/changelog.md)
- [Commits](https://github.com/schneegans/dynamic-badges-action/compare/v1.2.0...v1.3.0)

---
updated-dependencies:
- dependency-name: schneegans/dynamic-badges-action
  dependency-type: direct:production
  update-type: version-update:semver-minor
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`15203e8`](https://github.com/KennethEnevoldsen/asent/commit/15203e8d5bb69ad8c8fbc6f5d0861a6278d5f587))

* Merge pull request #30 from KennethEnevoldsen/workflow-patch

Fixed error causing workflow to pass ([`806453a`](https://github.com/KennethEnevoldsen/asent/commit/806453a6637204079f0e5bcaa1449549b1f482dc))

* Fixed error causing workflow to pass

Fixed error causing workflow to pass when using tee operator ([`3467ddc`](https://github.com/KennethEnevoldsen/asent/commit/3467ddcce82744d0d60552108a764c25ab75dd2f))

* Merge pull request #29 from KennethEnevoldsen/dependabot/github_actions/MishaKav/pytest-coverage-comment-1.1.25

:arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.24 to 1.1.25 ([`a4faf14`](https://github.com/KennethEnevoldsen/asent/commit/a4faf14efa75ea042d95250d57698b1977322674))

* :arrow_up: Bump MishaKav/pytest-coverage-comment from 1.1.24 to 1.1.25

Bumps [MishaKav/pytest-coverage-comment](https://github.com/MishaKav/pytest-coverage-comment) from 1.1.24 to 1.1.25.
- [Release notes](https://github.com/MishaKav/pytest-coverage-comment/releases)
- [Commits](https://github.com/MishaKav/pytest-coverage-comment/compare/v1.1.24...v1.1.25)

---
updated-dependencies:
- dependency-name: MishaKav/pytest-coverage-comment
  dependency-type: direct:production
  update-type: version-update:semver-patch
...

Signed-off-by: dependabot[bot] &lt;support@github.com&gt; ([`79fd19e`](https://github.com/KennethEnevoldsen/asent/commit/79fd19ef28b01e3a76c448da9f0681e188b60734))

* formatted to black ([`9244dbc`](https://github.com/KennethEnevoldsen/asent/commit/9244dbca8f86becd5c77bd7aa00b81bec3c4dc13))

* updated setup ([`ffedeed`](https://github.com/KennethEnevoldsen/asent/commit/ffedeed83c6fcaceb6c2a26692dfe845b7fc52a4))

* relaxed black version ([`6cc515b`](https://github.com/KennethEnevoldsen/asent/commit/6cc515b25999b3bc63f3a209aa2e828a0a6cbd38))

* updated black requirements ([`4af51ea`](https://github.com/KennethEnevoldsen/asent/commit/4af51ea01acdd85c4329d647a838e5b9709db615))

* bumped workflows versions ([`98a9e5e`](https://github.com/KennethEnevoldsen/asent/commit/98a9e5ea6cdf00f6675342ede80ebcc4a4906952))

* removed boilerplate test code ([`1407d90`](https://github.com/KennethEnevoldsen/asent/commit/1407d90408a0554572a4f127189c2f5b1104f572))

* updated workflows ([`9b68836`](https://github.com/KennethEnevoldsen/asent/commit/9b68836842bd4f06e4019ff535220a58b68813da))

* intro notebook tests as intended ([`1775c6a`](https://github.com/KennethEnevoldsen/asent/commit/1775c6ae1c766f6387d07db6ac2b1c68cd9396bf))

* ignore customizing pipeline test ([`4953029`](https://github.com/KennethEnevoldsen/asent/commit/49530295857d8f1c28dfca0fba3018c741251f0f))

* Added note to tutorial ([`3fd8d95`](https://github.com/KennethEnevoldsen/asent/commit/3fd8d95e468b5aef0b1c106cef6de3520f213d21))

* updating run in Colab link ([`e329779`](https://github.com/KennethEnevoldsen/asent/commit/e329779d42594b26e01761b3224415197d18b070))

* Merge pull request #25 from KennethEnevoldsen/Update/CI

Update/CI ([`98b4dc8`](https://github.com/KennethEnevoldsen/asent/commit/98b4dc8f7e9e7bcb41a956c4e03ad9e601d16be9))

* set black version ([`bf8d096`](https://github.com/KennethEnevoldsen/asent/commit/bf8d09691c6745333953b41c84279cfb72c72089))

* set black version ([`5bdd5e4`](https://github.com/KennethEnevoldsen/asent/commit/5bdd5e4a5364d532f4a81018e1fd5b0057632d43))

* Updated CI ([`5217f0d`](https://github.com/KennethEnevoldsen/asent/commit/5217f0d01063005a2dfe98982bb99e00c935f629))

* updated ignore ([`de3d9ac`](https://github.com/KennethEnevoldsen/asent/commit/de3d9ac18b9506bc56b6d1e9024f0a5ec910b309))

* Merge pull request #22 from martbern/main

Merge misc. correction by martbern ([`e8f1aea`](https://github.com/KennethEnevoldsen/asent/commit/e8f1aeaca7b3252f3337fabf8c5bd6a65d9df158))

* Update tutorials/introduction.ipynb ([`0a1cca9`](https://github.com/KennethEnevoldsen/asent/commit/0a1cca9ffab6c512b1980fd687a1cc75d56fe43d))

* Update tutorials/customizing_your_pipeline.ipynb ([`bc3c1f6`](https://github.com/KennethEnevoldsen/asent/commit/bc3c1f617d01a3689172b36bd64d77caba68bc5e))

* Update requirements.txt ([`fa88a91`](https://github.com/KennethEnevoldsen/asent/commit/fa88a914d867a9794a88f197a630bf76b87fa57c))

* Delete Miniforge3-MacOSX-arm64.sh ([`e83a3f0`](https://github.com/KennethEnevoldsen/asent/commit/e83a3f071bee320f52ec34dacb92dc0f179e9598))

* Merge branch &#39;main&#39; into main ([`5155c7a`](https://github.com/KennethEnevoldsen/asent/commit/5155c7a6d4bb2fbae2cec160818daa5648aebdfa))

* Merge pull request #23 from EmilStenstrom/patch-1

Fix missing links and references to separate project ([`1805a0b`](https://github.com/KennethEnevoldsen/asent/commit/1805a0b8aecd190616af62b7a8986c1941222184))

* Fix missing links and references to separate project ([`89a22cf`](https://github.com/KennethEnevoldsen/asent/commit/89a22cf92a71ae143c037dc9dfee30f466b2c350))

* Misc. ([`399d925`](https://github.com/KennethEnevoldsen/asent/commit/399d925973fa8bd0aff4fc16ad7311b1af294e8c))

* Misc. ([`a411756`](https://github.com/KennethEnevoldsen/asent/commit/a411756d31ecc1a74f1a262623dfa311e9b67ef9))

* Agumenty links in readme ([`de55a32`](https://github.com/KennethEnevoldsen/asent/commit/de55a32476849feac05918053c3538c0e642f968))

* updated news ([`88a5843`](https://github.com/KennethEnevoldsen/asent/commit/88a5843770d21dae20da8c09fdbd4991ee8a15c1))

* added intensifier to visualize tests ([`02f529c`](https://github.com/KennethEnevoldsen/asent/commit/02f529c48437b953134b26e596aef8bb9eadad8c))

* added cap_diff when testiing intensifiers ([`b01678a`](https://github.com/KennethEnevoldsen/asent/commit/b01678ac514e34fd30853625f7d714fb9cb26b54))

* added more tests with intensifiers ([`88353a5`](https://github.com/KennethEnevoldsen/asent/commit/88353a59d3498636f6fd04f1e6741607994efe2e))

* Updated readme ([`2aeb987`](https://github.com/KennethEnevoldsen/asent/commit/2aeb98707925895aa316d75d77a152581f04554f))

* bumping version id ([`5eff3ef`](https://github.com/KennethEnevoldsen/asent/commit/5eff3ef70644ec388eab022891ec6a715702e237))

* fixed unraised error ([`122a37b`](https://github.com/KennethEnevoldsen/asent/commit/122a37bb995c601308b235252a53216f682ca073))

* Added overview of components ([`db26b58`](https://github.com/KennethEnevoldsen/asent/commit/db26b58a8b4986167710c0971db987ffe29dcedf))

* Merge pull request #20 from KennethEnevoldsen/feature/visualiser

updated test suite ([`5096231`](https://github.com/KennethEnevoldsen/asent/commit/5096231ddeffb05394b7c60b5a1910dbdb24aee2))

* updated test suite ([`001f88f`](https://github.com/KennethEnevoldsen/asent/commit/001f88fa2d0023c101393bb0cc35adf1a26816d3))

* Merge pull request #19 from KennethEnevoldsen/feature/visualiser

Added analysis visualizer ([`478b8d9`](https://github.com/KennethEnevoldsen/asent/commit/478b8d99a9a6cef3fc8cd6d4ebf1745d1dfa9d11))

* formatted to black ([`58d8de0`](https://github.com/KennethEnevoldsen/asent/commit/58d8de0c21cf60ef8b88b6bce5b81f1ad3255a1d))

* added test ([`31d4bf0`](https://github.com/KennethEnevoldsen/asent/commit/31d4bf093ad30708dfd95ca93f47bcab4fc537b2))

* updated documentation ([`0c7ca7f`](https://github.com/KennethEnevoldsen/asent/commit/0c7ca7f13c7c98d3f93c9d72d519ccd26d4dad5a))

* Added analysis visualizer ([`ccf9b58`](https://github.com/KennethEnevoldsen/asent/commit/ccf9b581cb35519b11daf2c25a7bb1c732e96270))

* Merge pull request #17 from KennethEnevoldsen/feature/tutorials_workflow

added tests to tutorials ([`c2fe7ba`](https://github.com/KennethEnevoldsen/asent/commit/c2fe7ba287763c9d0851a82f3fae9c80b83dc9f5))

* Tutorials no longer raises a valueError ([`d07f387`](https://github.com/KennethEnevoldsen/asent/commit/d07f387c620d873c3ae7cc53f64a2b4d024f6e4a))

* check that workflow fails if tut. fails ([`e69af4c`](https://github.com/KennethEnevoldsen/asent/commit/e69af4c0fcd6344f0a4adab3439ea35281b84512))

* minor fix ([`6ea50a6`](https://github.com/KennethEnevoldsen/asent/commit/6ea50a69b5663cb402cd1ecff8e2b3eb55725f3f))

* Added description to workflow ([`704bd9a`](https://github.com/KennethEnevoldsen/asent/commit/704bd9a72e2e2923278b1d02dbb7cfd249e065dc))

* minor fixes to black workflow ([`99b4c0f`](https://github.com/KennethEnevoldsen/asent/commit/99b4c0ff34dcbefb07bf822f98327afdb3612e55))

* updated tutorials workflow ([`3411957`](https://github.com/KennethEnevoldsen/asent/commit/3411957d80d663db01ac83444da9473ff23bb3b3))

* added tests to tutorials ([`816514c`](https://github.com/KennethEnevoldsen/asent/commit/816514ce0e53d694f78b152e36d738e1c76735c6))

* format to black 🕶 ([`f4717f5`](https://github.com/KennethEnevoldsen/asent/commit/f4717f506622c5833b1f39c8c544d5c752a18352))

* Extended coverage of tests ([`758de96`](https://github.com/KennethEnevoldsen/asent/commit/758de96ca4434b7e1c29010418d58b7663bca2c8))

* include the sv lexicon ([`0974bcc`](https://github.com/KennethEnevoldsen/asent/commit/0974bcc37fa25e0e68e9017c1ec3b95ac1f63051))

* bumbed version number to accomodate new changes ([`d3d82df`](https://github.com/KennethEnevoldsen/asent/commit/d3d82df521fe08f9aa488a95d2a99c9b22bb1786))

* Minor updates to documentation ([`c055334`](https://github.com/KennethEnevoldsen/asent/commit/c05533442379aacb776f0ff7b42c78c10e40108c))

* Fixed bug when dealing with empty strings ([`608ea15`](https://github.com/KennethEnevoldsen/asent/commit/608ea157db708dbd7c580b8e70538f87af49c46c))

* formatted to black 🕶 ([`8c7974e`](https://github.com/KennethEnevoldsen/asent/commit/8c7974e14730c2de75ea681c4b217c25b0024e6b))

* converted workflow to the official implementation ⬛️ ([`b46d896`](https://github.com/KennethEnevoldsen/asent/commit/b46d8963044be20aa94b927c3c726fe95ceaadb5))

* minor formatting ([`a9b2361`](https://github.com/KennethEnevoldsen/asent/commit/a9b2361c361680d98fae8f081a009529d961c24a))

* Fixed bug with missing no lexicon 🪲 ([`28495aa`](https://github.com/KennethEnevoldsen/asent/commit/28495aac394eb71db007c79e6ccb2a539238315c))

* Fixed bug with missing no lexicon 🪲 ([`e6d97f0`](https://github.com/KennethEnevoldsen/asent/commit/e6d97f0f797cfb2e324d3ae5b36db132b6ad726c))

* extended test suite ([`1b3e805`](https://github.com/KennethEnevoldsen/asent/commit/1b3e8053a8fe5b7444df0f7fc86c36174373cf97))

* removed unused function ([`d1df00a`](https://github.com/KennethEnevoldsen/asent/commit/d1df00aaa33f35bf63881ae94202d7a26e196e85))

* added test to data classes ([`2b0c688`](https://github.com/KennethEnevoldsen/asent/commit/2b0c6881098c999b7788d7d83e9f1ad8b99a7ae4))

* formatted to black 🕶 ([`8e27228`](https://github.com/KennethEnevoldsen/asent/commit/8e2722840c70f2bd3cdb123fd83caca186120fa8))

* updated requirements ([`314c7f3`](https://github.com/KennethEnevoldsen/asent/commit/314c7f3230a158ab75e6bd267eabe88e75ccbf9a))

* fixed tests ([`deedeb2`](https://github.com/KennethEnevoldsen/asent/commit/deedeb2e297d2342ba958288b09ae0c0803c306e))

* updated black  workflow ([`12ada34`](https://github.com/KennethEnevoldsen/asent/commit/12ada341fd20aa2a8e4dad1cd9acfabe7e9c61d0))

* updated tests for wider coverage ([`90ad0b8`](https://github.com/KennethEnevoldsen/asent/commit/90ad0b846ff7e6175d22ef6f19e4f8043aa0ff31))

* renamed se to sv ([`a23bd9a`](https://github.com/KennethEnevoldsen/asent/commit/a23bd9ab09e8fb8b7ff062d01cbe246bf7ec4722))

* added force arg to components ([`d6da09a`](https://github.com/KennethEnevoldsen/asent/commit/d6da09a4ec0eea41776e0f1c0e937a8bd0a4ac7b))

* added force argument to components ([`3710102`](https://github.com/KennethEnevoldsen/asent/commit/3710102500bbf085ea0c3879676b53e869d5f7a6))

* added black autoformat workflow ([`20fe9b1`](https://github.com/KennethEnevoldsen/asent/commit/20fe9b1ea70c98137044e86d614785671afd6e66))

* updated test for wider coverage ([`a0fe9c4`](https://github.com/KennethEnevoldsen/asent/commit/a0fe9c41f0cffdd47ed99db10c40b619dcace2fe))

* improved test suite ([`abcb726`](https://github.com/KennethEnevoldsen/asent/commit/abcb7268bab05ba6c695d12ff18a0a668abf4c66))

* cleanup ([`834551a`](https://github.com/KennethEnevoldsen/asent/commit/834551a5e967bd28c36dad3f6be3291e13b0880d))

* updated documentation ([`d1b7415`](https://github.com/KennethEnevoldsen/asent/commit/d1b7415c365b8ca3687ebd155dafcf16f1a5af89))

* updated documentation ([`d2d9715`](https://github.com/KennethEnevoldsen/asent/commit/d2d9715224f27b2c81208944161b41fed0382fb9))

* grammatical fixes to the documentation ([`99378cd`](https://github.com/KennethEnevoldsen/asent/commit/99378cdcdf1efc5b63fbd30795907124cedb0e84))

* add sphinx design to doc req ([`c2f5ae6`](https://github.com/KennethEnevoldsen/asent/commit/c2f5ae6b93fd983c723317264c1cd9049be356b2))

* update test to accomodate recent changes ([`84e16db`](https://github.com/KennethEnevoldsen/asent/commit/84e16db0c98f82b3105e6e60ba546b7c0dc57d1a))

* extensive documentation update ([`a599f55`](https://github.com/KennethEnevoldsen/asent/commit/a599f555efbe3db21cb609fe4009ee1a01696c3a))

* added tut img ([`f0f0239`](https://github.com/KennethEnevoldsen/asent/commit/f0f023914e5bed847929dcb8d9e7aca8f6915a92))

* another sv pred ([`ba02d84`](https://github.com/KennethEnevoldsen/asent/commit/ba02d84d86f4a8dd63558ab69bda4b00c04b127a))

* added sv pred ([`017d399`](https://github.com/KennethEnevoldsen/asent/commit/017d399865c9795a3ea40e1d7b559c33d0b9ffbf))

* fixed negation ([`2ee7594`](https://github.com/KennethEnevoldsen/asent/commit/2ee75949bbc25444f92eafd955a35460e8311f6b))

* fixed name issue ([`83450b2`](https://github.com/KennethEnevoldsen/asent/commit/83450b2bd784f6337e78741cd9792b87efd5d926))

* added version id to init ([`540259d`](https://github.com/KennethEnevoldsen/asent/commit/540259dea7a88d98ed0e4780fef1e9aaa1948cbb))

* updated manifest ([`34b19b2`](https://github.com/KennethEnevoldsen/asent/commit/34b19b2015e549b7c1c08a22738f8f72cf73264a))

* minor documentation tweak ([`0695b7d`](https://github.com/KennethEnevoldsen/asent/commit/0695b7d48b0573b961a54f1cbbb17376b46cd104))

* added working introduction ([`974f1a0`](https://github.com/KennethEnevoldsen/asent/commit/974f1a02316640a3f437e48c99e490a7bea53220))

* updated readme ([`1f915f2`](https://github.com/KennethEnevoldsen/asent/commit/1f915f2526c601fe3b10191ca5f7dfb447980486))

* added model pred ([`63889e2`](https://github.com/KennethEnevoldsen/asent/commit/63889e26613fe9122a9f736a16b850ea99b88e21))

* added an introduction ([`4b07bb1`](https://github.com/KennethEnevoldsen/asent/commit/4b07bb1eefe776282cb7bdfc3272dfcdfe3ceaa1))

* updated manifest.in ([`8e07d93`](https://github.com/KennethEnevoldsen/asent/commit/8e07d9346d4c539db41baac2ac8bbc2b60d4e850))

* add images ([`32f6d95`](https://github.com/KennethEnevoldsen/asent/commit/32f6d954bc429788d540c1dc79ec81b0cfd1b229))

* formatted to black ([`6a4bb17`](https://github.com/KennethEnevoldsen/asent/commit/6a4bb17255deea66b5da97b927225c5e5a217591))

* minor fixes ([`8045025`](https://github.com/KennethEnevoldsen/asent/commit/8045025c67dc8fcca1697d4e7b009695ae8fe599))

* added needed links ([`f29dee7`](https://github.com/KennethEnevoldsen/asent/commit/f29dee72a6528730e7fa343058bac4d8609e07e4))

* removed broken link ([`07425c9`](https://github.com/KennethEnevoldsen/asent/commit/07425c9ab0765c334eaf80b1b714d5291d70acf4))

* fixed workflow to correct secret name ([`75b11c0`](https://github.com/KennethEnevoldsen/asent/commit/75b11c0981281be8bad21dfeeadca862070473a2))

* updating readme ([`d905b04`](https://github.com/KennethEnevoldsen/asent/commit/d905b041d70a48791e5e35baca167eee0e5b3d52))

* fixed cit ([`1e1f8ac`](https://github.com/KennethEnevoldsen/asent/commit/1e1f8ac52ccff81f443a9d716993eba512424528))

* updated workflow ([`ed6f399`](https://github.com/KennethEnevoldsen/asent/commit/ed6f399ce0f8a4f8c149e3d08910b85c9fd5bfde))

* fixed coverage badge ([`5015e2c`](https://github.com/KennethEnevoldsen/asent/commit/5015e2c0f71f517972870b288f11ed807f8bb3fb))

* excluded ubuntu py3.9 to avoid running it twice ([`9ce8b56`](https://github.com/KennethEnevoldsen/asent/commit/9ce8b56374f1a6e12f01af6f4cd7d89221b60674))

* updating indexes ([`13f817d`](https://github.com/KennethEnevoldsen/asent/commit/13f817d925508d23b2a2cc7f6e9c07942a535a62))

* updated toctree ([`c9ee67b`](https://github.com/KennethEnevoldsen/asent/commit/c9ee67b58a88e388c2f12c04147538b8bce1eb86))

* fixed error in workflow ([`dc7543e`](https://github.com/KennethEnevoldsen/asent/commit/dc7543e35540126b83ff45a96c5153795530c27e))

* fixed invalid CI ([`1390ab9`](https://github.com/KennethEnevoldsen/asent/commit/1390ab92480b949a7567d6ceb6af7cc160261581))

* fixed pytest CI ([`7b091fd`](https://github.com/KennethEnevoldsen/asent/commit/7b091fd00d51c7dc8c3c86db46eeeb8ab083a58c))

* resized logo ([`0beda60`](https://github.com/KennethEnevoldsen/asent/commit/0beda60f7f3fb4fa24f15a14599a3a8c573415c8))

* fixed logo not rendering ([`a5f6d76`](https://github.com/KennethEnevoldsen/asent/commit/a5f6d7657ae8a74f0a2ac8c4d82ca2236916a29c))

* updated code quality ([`cf63c47`](https://github.com/KennethEnevoldsen/asent/commit/cf63c47305f361a3feda662ffa4a35f971a447fe))

* General update of documentation ([`e7ba616`](https://github.com/KennethEnevoldsen/asent/commit/e7ba6163c8f20cf7603f6628c22b067ccca820ed))

* added matplotlib to requirements ([`5e99b73`](https://github.com/KennethEnevoldsen/asent/commit/5e99b7303e82e88c0770c1b97e345e2ed3ea00ff))

* simplified tests ([`ea8576e`](https://github.com/KennethEnevoldsen/asent/commit/ea8576e4296965f932eca39865e986c31771314f))

* Initial documentation commit ([`9869ffe`](https://github.com/KennethEnevoldsen/asent/commit/9869ffeba65337b18f9bfbf73b105252d5cf7fa2))

* cleaning up the repo ([`9a5cddf`](https://github.com/KennethEnevoldsen/asent/commit/9a5cddfd689066844fd82f2f0e48d7dfd5b94707))

* updated readme w. cit info ([`f0dcae1`](https://github.com/KennethEnevoldsen/asent/commit/f0dcae15bafe825a20693203791a640293c0d2f8))

* bumped version id ([`f9e5459`](https://github.com/KennethEnevoldsen/asent/commit/f9e545996ba4c45e07f9081d4852880413a50e19))

* updated readme moving more to docs ([`0ec82c1`](https://github.com/KennethEnevoldsen/asent/commit/0ec82c10ed510435005db1d06a77f5ae3ebac7d0))

* fixed ignored ([`7ace6da`](https://github.com/KennethEnevoldsen/asent/commit/7ace6da38a93be8bb1b9bddfa597e4c526b8b06f))

* updated requirements ([`fb90cd3`](https://github.com/KennethEnevoldsen/asent/commit/fb90cd3e1975910515354a7194db102e4f69dda7))

* first readme update ([`6df97b9`](https://github.com/KennethEnevoldsen/asent/commit/6df97b92696af1c2318ebbff618c6c2b7311c55a))

* Addded logo to readme ([`79f381a`](https://github.com/KennethEnevoldsen/asent/commit/79f381a73ded190b321cafad913aad273c1a1ce8))

* removed test from coverage ([`1f0058b`](https://github.com/KennethEnevoldsen/asent/commit/1f0058bf6a5fbdbc55b13e98f11e17263c83cb8d))

* updated requirements ([`705204c`](https://github.com/KennethEnevoldsen/asent/commit/705204c19f776bc04c4c3785936d3d135e917016))

* added coverage run ([`a320652`](https://github.com/KennethEnevoldsen/asent/commit/a3206520d96c61e5ed3abb42851712c280360434))

* initial workflow push ([`955116d`](https://github.com/KennethEnevoldsen/asent/commit/955116db945bf6d983c2530db814bbbb4a609dbe))

* Getted tests to work ([`9da18bb`](https://github.com/KennethEnevoldsen/asent/commit/9da18bb0c41d1c40391fed3db6de82a5e749d8fb))

* rm vscode ([`c3df15b`](https://github.com/KennethEnevoldsen/asent/commit/c3df15bbffb7a7d0e93056287be40e6d9c2b267a))

* initial commit ([`60a6296`](https://github.com/KennethEnevoldsen/asent/commit/60a629607394e5e9eb7e2585928953b51268c8ea))
